@@ -84,7 +84,7 @@ server_teardown (ServerData *sd, gconstpointer test_data)
 		soup_server_remove_handler (sd->server, iter->data);
 	g_slist_free_full (sd->handlers, g_free);
 
-	soup_test_server_quit_unref (sd->server);
+	g_clear_pointer (&sd->server, soup_test_server_quit_unref);
 	g_clear_pointer (&sd->base_uri, soup_uri_free);
 	g_clear_pointer (&sd->ssl_base_uri, soup_uri_free);
 }
@@ -365,7 +365,7 @@ multi_server_callback (SoupServer *server, SoupMessage *msg,
 
 	g_assert_cmpint (g_inet_socket_address_get_port (iaddr), ==, uri->port);
 
-	// FIXME ssl
+	/* FIXME ssl */
 
 	soup_message_set_response (msg, "text/plain",
 				   SOUP_MEMORY_TAKE, uristr, strlen (uristr));
@@ -1284,6 +1284,8 @@ do_steal_connect_test (ServerData *sd, gconstpointer test_data)
 	SoupMessage *msg;
 	const char *handled_by;
 
+	SOUP_TEST_SKIP_IF_NO_TLS;
+
 	proxy = soup_test_server_new (SOUP_TEST_SERVER_IN_THREAD);
 	proxy_uri = soup_test_server_get_uri (proxy, SOUP_URI_SCHEME_HTTP, "127.0.0.1");
 	soup_server_add_handler (proxy, NULL, proxy_server_callback, NULL, NULL);
